@@ -14,7 +14,7 @@ sub run {
 
     my $res = HTTP::Tiny->new->get( $url, {
         headers => {
-            'Content-Type' => 'application/vnd.api+json',
+            'Accept' => 'application/vnd.api+json',
         },
     });
 
@@ -102,7 +102,7 @@ PONAPI::CLI::RunQuery - ponapi CLI query runner
 
 =head1 VERSION
 
-version 0.002014
+version 0.002015
 
 =head1 AUTHORS
 
